<h1 align="center">
<img src="https://github.com/pyfar/gallery/raw/main/docs/resources/logos/pyfar_logos_fixed_size_pyrato.png" width="300">
</h1><br>



[![PyPI version](https://badge.fury.io/py/pyrato.svg)](https://badge.fury.io/py/pyrato)
[![Documentation Status](https://readthedocs.org/projects/pyrato/badge/?version=stable)](https://pyrato.readthedocs.io/en/stable/?badge=stable)
[![CircleCI](https://circleci.com/gh/pyfar/pyrato.svg?style=shield)](https://circleci.com/gh/pyfar/pyrato)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/pyfar/gallery/main?labpath=docs/gallery/interactive/pyfar_introduction.ipynb)


Getting Started
===============

The [`pyfar workshop`](https://mybinder.org/v2/gh/pyfar/gallery/main?labpath=docs/gallery/interactive/pyfar_introduction.ipynb) gives an overview of the most important pyfar functionality and is a good starting point. It is part of the [`pyfar example gallery`](https://pyfar-gallery.readthedocs.io/en/latest/examples_gallery.html) that also contains more specific and in-depth examples that can be executed interactively without a local installation by clicking the mybinder.org button on the respective example. The [`pyrato documentation`](https://pyrato.readthedocs.io) gives a detailed and complete overview of pyrato. All these information are available from [`pyfar.org`](https://pyfar.org).


Installation
============

Use pip to install pyrato

    pip install pyrato

If the installation fails, please check out the [help section](https://pyfar-gallery.readthedocs.io/en/latest/help).

Contributing
============

Check out the [contributing guidelines](https://pyfar.readthedocs.io/en/stable/contributing.html) if you want to become part of pyfar.
